@@ -12,7 +12,8 @@ my @variables = qw(
    formatting_rules_node formatting_rules_link backlinks_in_title template_path
    custom_template_path geo_handler ellipsoid gmaps_api_key centre_long
    centre_lat default_gmaps_zoom default_gmaps_search_zoom force_wgs84
-   licence_name licence_url licence_info_url
+   licence_name licence_url licence_info_url moderation_requires_password
+   enable_node_image enable_common_categories enable_common_locales
 );
 my @questions = map { $_ . "__qu" } @variables;
 OpenGuides::Config->mk_accessors( @variables );
@@ -66,7 +67,11 @@ sub _init {
                      use_plucene => 1,
                      indexing_directory => "/usr/lib/cgi-bin/openguides/indexes/",
                      enable_page_deletion => 0,
+                     moderation_requires_password => 1,
                      admin_pass => "Change This!",
+                     enable_node_image => 1,
+                     enable_common_categories => 1,
+                     enable_common_locales => 1,
                      site_name => "Unconfigured OpenGuides site",
                      navbar_on_home_page => 1,
                      home_name => "Home",
@@ -130,8 +135,12 @@ sub _init {
         use_plucene => "Do you want to use Plucene for searching? (recommended, but see Changes file before saying yes to this if you are upgrading)",
         indexing_directory => "What directory can I use to store indexes in for searching? ***NOTE*** This directory must exist and be writeable by the user that your script will run as.  See README for more on this.",
         enable_page_deletion => "Do you want to enable page deletion?",
+        moderation_requires_password => "Is the admin password required for moderating pages?",
         admin_pass => "Please specify a password for the site admin.",
         stylesheet_url => "What's the URL of the site's stylesheet?",
+        enable_node_image => "Should nodes be allowed to have an externally hosted image?",
+        enable_common_categories => "Do you want a common list of categories shown on all node pages?",
+        enable_common_locales => "Do you want a common list of locales shown on all node pages?",
         site_name => "What's the site called? (should be unique)",
         navbar_on_home_page => "Do you want the navigation bar included on the home page?",
         home_name => "What should the home page of the wiki be called?",
