@@ -3,7 +3,7 @@ use strict;
 our $VERSION = '0.10';
 
 use CGI qw( :standard );
-use CGI::Wiki::Plugin::Locator::Grid;
+use Wiki::Toolkit::Plugin::Locator::Grid;
 use File::Spec::Functions qw(:ALL);
 use OpenGuides::Template;
 use OpenGuides::Utils;
@@ -64,7 +64,7 @@ sub new {
         %locator_params = ( x => "easting", y => "northing" );
     }
 
-    my $locator = CGI::Wiki::Plugin::Locator::Grid->new( %locator_params );
+    my $locator = Wiki::Toolkit::Plugin::Locator::Grid->new( %locator_params );
     $wiki->register_plugin( plugin => $locator );
     $self->{locator} = $locator;
 
@@ -75,7 +75,7 @@ sub new {
 
   my $wiki = $search->wiki;
 
-An accessor; returns the underlying L<CGI::Wiki> object.
+An accessor; returns the underlying L<Wiki::Toolkit> object.
 
 =cut
 
@@ -118,6 +118,19 @@ precedence over C<return_output>.
 These two parameters exist to make testing easier; you probably don't
 want to use them in production.
 
+
+In case you're struggling to follow the code, it does the following:
+1) Processes the parameters, and bails out if it hit a problem with them
+2) If a search string was given, do a text search
+3) If distance search paramaters were given, do a distance search
+4) If no search has occured, print out the search form
+5) If an error occured, bail out
+6) If we got a single hit on a string search, redirect to it
+7) If no results were found, give an empty search results page
+8) Sort the results by either score or distance
+9) Decide which results to show, based on paging
+10) Display the appropriate page of the results
+
 =back
 
 =cut
@@ -136,6 +149,7 @@ sub run {
     }
 
     my %tt_vars = (
+                   format      => $args{'vars'}->{'format'},
                    ss_version  => $VERSION,
                    ss_info_url => 'http://openguides.org/page/search_help'
                   );
@@ -429,7 +443,7 @@ sub _run_phrase_search {
     my %contents_res = $wiki->search_nodes( $phrase );
 
     # Rationalise the scores a little.  The scores returned by
-    # CGI::Wiki::Search::Plucene are simply a ranking.
+    # Wiki::Toolkit::Search::Plucene are simply a ranking.
     my $num_results = scalar keys %contents_res;
     foreach my $node ( keys %contents_res ) {
         $contents_res{$node} = int( $contents_res{$node} / $num_results ) + 1;
@@ -680,7 +694,7 @@ sub process_params {
     return $self;
 }
 
-# thin wrapper around OpenGuides::Template
+# thin wrapper around OpenGuides::Template, or OpenGuides::Feed
 sub process_template {
     my ($self, %args) = @_;
 
@@ -688,12 +702,34 @@ sub process_template {
     $tt_vars->{not_editable} = 1;
     $tt_vars->{not_deletable} = 1;
     return %$tt_vars if $self->{return_tt_vars};
-    my $output =  OpenGuides::Template->output(
+
+    # Do we want a feed, or TT html?
+    my $output;
+    if($tt_vars->{'format'}) {
+        my $format = $tt_vars->{'format'};
+        my @nodes = @{$tt_vars->{'results'}};
+
+        my $feed = OpenGuides::Feed->new(
+                                               wiki       => $self->wiki,
+                                               config     => $self->config,
+                                               og_version => $VERSION,
+                                        );
+        $feed->set_feed_name_and_url_params(
+                    "Search Results for ".$tt_vars->{search_terms},
+                    "search.cgi?search=".$tt_vars->{search_terms}
+        );
+
+        $output  = "Content-Type: ".$feed->default_content_type($format)."\n";
+        $output .= $feed->build_mini_feed_for_nodes($format,@nodes);
+    } else {
+        $output =  OpenGuides::Template->output(
                                                 wiki     => $self->wiki,
                                                 config   => $self->config,
                                                 template => "search.tt",
                                                 vars     => $tt_vars,
                                               );
+    }
+
     return $output if $self->{return_output};
 
     print $output;
